Skip to contents

This function returns the description of a given distribution.

Usage

desc(dist)

# S4 method for class 'ddf'
desc(dist)

Arguments

dist

A ddf object, the distribution.

Value

A character, the description text of the ddf object.

Examples

desc(ddf(1:3))
#> [1] "A discrete distribution with finite support"
desc(ddf(1:3, desc = "My custom description"))
#> [1] "My custom description"