Skip to contents

This function calculates the range of a ddf distribution.

Usage

distribution_range(dist)

Arguments

dist

A ddf object, the distribution.

Value

A double.

Details

The range is the length of the narrowest interval containing the entire support.

Examples

# Range of the Rademacher distribution
distribution_range(rademacher())
#> [1] 2