Skip to contents

This function calculates the excess kurtosis of a ddf distribution.

Usage

excess_kurtosis(dist)

Arguments

dist

A ddf object, the distribution.

Value

A double.

Details

The excess kurtosis is simply defined as the kurtosis() minus 3, hence we only refer to the linked help page for some more details.

See also

Examples

excess_kurtosis(unif(8))
#> [1] -1.238095