Skip to contents

This function calculates the kurtosis of a ddf distribution.

Usage

kurtosis(dist)

Arguments

dist

A ddf object, the distribution.

Value

A double.

Details

The kurtosis is given by the fourth standardized moment, thus for some more details one can consult standardized_moment().

It measures the "tailedness" of a distribution, i.e. the heaviness of its tails. A higher kurtosis indicates a higher propensity to produce outliers.

Examples

# The rademacher distribution has a very low kurtosis
# (in fact it is as minimal as possible)
kurtosis(rademacher())
#> [1] 1
# A binomial distribution with relatively low probability
# has rather high kurtosis
kurtosis(bin(10, 1e-4))
#> [1] 1002.5