Skip to contents

This function writes a detailed report given a ddf distribution involving most properties such as various measures of central tendency and dispersion, skewness and kurtosis and more.

Usage

report(dist)

Arguments

dist

A ddf object, the distribution.

Value

A character.

Examples

# Write a report on a binomial distribution
# and output it using cat
cat(report(bin(20, 0.4)))
#> The given distribution could be described as "Binomial distribution with parameters n = 20 and p = 0.4".
#> 
#> It has a mean/expected value of 8, the average of its mode(s) is given by 8 and the average of its median(s) is 8. It is a unimodal distribution.
#> 
#> Regarding its dispersion, calculating its variance yields 4.8 which implies a standard deviation of 2.19089023002066. When talking about other measures of variability, one can assert that the distribution's range constitutes 20 over its 21 elements, whereas its interquartile range is given by 3 since the (smallest) first quartile is 6 and the (largest) third quartile is 9.
#> 
#> It has a skewness of 0.0912870929175291 (measured using Fisher's moment coefficient of skewness) and with an excess kurtosis of -0.0916666666666668 (and hence kurtosis of 2.90833333333333) it is a platykurtic, also called platykurtotic, distribution.
#> 
#> Lastly, it can be noted that its entropy, measured in bits, is 3.17713982274889.