Skip to contents

This function calculates the skewness of a ddf distribution.

Usage

skew(dist)

Arguments

dist

A ddf object, the distribution.

Value

A double.

Details

"Skewness" here refers to Fisher's moment coefficient of skewness, also known under Pearson's instead of Fisher's name or simply as the moment coefficient of skewness. It is given by the third standardized moment, see also the help standardized_moment().

A distribution with negative skew has a longer left tail, its mass is concentrated to the right end of its support and when plotting its probability mass function one gets a right-leaning curve.

Analogously, a distribution with positive skew has a longer right tail, its mass is concentrated to the left end of its support and when plotting its probability mass function one gets a left-leaning curve.

Examples

# A binomial distribution with success probability
# p < 0.5 has positive skew
skew(bin(10, 0.25))
#> [1] 0.3651484
# whereas one with p > 0.5 has negative skew
skew(bin(10, 0.75))
#> [1] -0.3651484