Skip to contents

This function calculates the standard deviation of a ddf distribution.

Usage

standard_deviation(dist)

Arguments

dist

A ddf object, the distribution.

Value

A double.

Details

The standard deviation is the square root of the variance (which itself is the second central moment). For more details see variance() or better directly central_moment().

Examples

# Standard deviation of a hypergeometric distribution
standard_deviation(hypergeometric(20, 7, 3))
#> [1] 0.781446