Skip to contents

This function returns the support of a given distribution as a numerical vector.

Usage

supp(dist)

# S4 method for class 'ddf'
supp(dist)

Arguments

dist

A ddf object, the distribution.

Value

Support as a numerical vector.

Details

The support of a function is defined as the points in the function's domain where it is non-zero.

Examples

supp(ddf(1:3))
#> [1] 1 2 3