Create a ddf object for the binomial distribution with the given parameters.
This function uses stats::dbinom() to calculate the distribution
efficiently.
Details
The binomial distribution with parameters \(n\) and \(p\) models the
number of successes when conducting \(n\) independent experiments with each
one being distributed according to the Bernoulli distribution with success
probability \(p\) (see also bernoulli()).
It has support \(\{0, \dots, n\}\) on which its probability mass function is given by $$p(k) = \binom{n}{k} p^k (1-p)^{n-k}.$$
See also
Other distributions:
benford(),
bernoulli(),
beta_binomial(),
geometric(),
hypergeometric(),
negative_bin(),
negative_hypergeometric(),
pois(),
rademacher(),
unif(),
zipf()