Use this function to create a new ddf object based on absolute frequencies
by passing the occurred observations and corresponding absolute frequencies
as vectors to it.
Details
Although the purpose of this package is to work with discrete distributions with finite support, it might still be helpful to use some of its functions for working with frequency counts. For example, one might want to calculate an interquartile range or the excess kurtosis.
The purpose of this function is to make this possible in a convenient way.
A new ddf object is created by dividing all frequency counts by the total
number of observations such that the resulting vector sums up to 1.
This function furthermore ensures the same quality checks as ddf() (see the
‘Details.’ section) and has the same behaviour when no frequencies are
passed, i.e. the probabilities are distributed uniformly over the specified
observations.