This function calculates the range of a ddf distribution.
Examples
# Range of the Rademacher distribution
distribution_range(rademacher())
#> [1] 2
This function calculates the range of a ddf distribution.
# Range of the Rademacher distribution
distribution_range(rademacher())
#> [1] 2