This function calculates the excess kurtosis of a ddf distribution.
Details
The excess kurtosis is simply defined as the kurtosis() minus 3, hence we
only refer to the linked help page for some more details.
Examples
excess_kurtosis(unif(8))
#> [1] -1.238095