This function creates a plot of the probability mass function of a ddf
distribution.
Usage
plot_pmf(
dist,
xlab = "x",
ylab = "P[X = x]",
col = "deepskyblue3",
main = NULL,
sub = NULL
)Details
For further details on the probability mass function, you may consult pmf().
You might also be interested in the generic base::plot() method for ddf
objects.
See also
Other plotting functions:
plot,ddf,missing-method,
plot_cdf()