This function calculates \(p\)-quantiles of a ddf distribution.
Details
A \(p\)-quantile of a random variable \(X\) is a value \(x\) such that $$\mathbb{P}[ X \le x] \ge p \qquad\text{ and }\qquad \mathbb{P}[X \ge x] \ge 1-p,$$ where \(\mathbb{P}\) denotes the probability operator.
In general, it is not unique which is the reason for this function to have
the method argument.
If
methodis set to "all", all values in the support which are a \(p\)- quantile of the given distribution are returned. This is the default behaviour.If
methodis set to "mean", the mean of all such values is returned.If
methodis set to "min" or "max", the respective elements of the \(p\)-quantiles in the support are returned.
See also
Other quantiles:
decile(),
percentile(),
quartile()