This function generates random samples of a given size based on a ddf
distribution.
To generate the samples, base::sample() is used.
Examples
# Simulate throwing a dice 5 times
samples(unif(6), 5)
#> [1] 2 1 5 2 2
This function generates random samples of a given size based on a ddf
distribution.
To generate the samples, base::sample() is used.
# Simulate throwing a dice 5 times
samples(unif(6), 5)
#> [1] 2 1 5 2 2