This function returns the support of a given distribution as a numerical vector.
Details
The support of a function is defined as the points in the function's domain where it is non-zero.
Examples
supp(ddf(1:3))
#> [1] 1 2 3
This function returns the support of a given distribution as a numerical vector.
The support of a function is defined as the points in the function's domain where it is non-zero.
supp(ddf(1:3))
#> [1] 1 2 3