Create a ddf object for the Zipf distribution with the given parameters.
Details
Zipf's law is an empirical law stating that the relative frequency of the \(n\)-th entry in a list of measured values, ordered in decreasing order, is inversely proportional to \(n\).
This can be generalized and formalized by the following inverse power law with exponent \(s\):
The generalized Zipf distribution on \(N\) symbols has support \(\{1, \dots, N\}\) on which its probability mass function is given by $$p(k) = \frac{1}{H_{N, s}} \frac{1}{k^s},$$ where \(H_{N, s}\) is a generalized harmonic number: $$H_{N, s} = \sum_{k=1}^{N} \frac{1}{k^s}.$$
For some examples where Zipf's law occurs and further details, we recommend the below linked Wikipedia article.
See also
Other distributions:
benford(),
bernoulli(),
beta_binomial(),
bin(),
geometric(),
hypergeometric(),
negative_bin(),
negative_hypergeometric(),
pois(),
rademacher(),
unif()